package com.ruoyi.generator.controller;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.generator.domain.Community.CommunityArticle;
import com.ruoyi.generator.domain.Community.CommunityArticleCollect;
import com.ruoyi.generator.domain.Community.CommunityLike;
import com.ruoyi.generator.service.ICommunityArticleService;
import com.ruoyi.generator.vo.CommunityArticleVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;
import java.util.Objects;

/**
 * 社区文章管理
 *
 * @author fangzhen
 */
@Api(tags = "社区文章管理")
@RestController
@RequestMapping("/community/article")
public class CommunityArticleController extends BaseController {
    @Autowired
    private ICommunityArticleService communityArticleService;


    /**
     * 获取文章列表信息
     */
    @ApiOperation("获取文章列表")
    @GetMapping("/list")
    //@Anonymous
    public TableDataInfo communityList(CommunityArticle communityArticle) {
        startPage();
        List<CommunityArticleVo> list = communityArticleService.selectCommunityArticleList(communityArticle);
        return getDataTable(list);
    }

    /**
     * 获取文章列表信息
     */
    @ApiOperation("文章点赞")
    @PostMapping("/like")
    //@Anonymous
    public AjaxResult like(@RequestBody CommunityLike communityLike) {
        if (Objects.isNull(communityLike.getArticleId()) || Objects.isNull(communityLike.getUserId())) {
            AjaxResult.error("文章或用户信息异常!");
        }
        boolean isSuccess = true;
        String message = "";
        CommunityLike like = communityArticleService.selectCommunityLikeById(communityLike);
        if (Objects.isNull(like)) {
            //新增点赞
            isSuccess = communityArticleService.insertCommunityLikeById(communityLike);
            message = "感谢点赞";
        } else {
            //删除点赞
            isSuccess = communityArticleService.deleteCommunityLikeById(like);
            message = "取消点赞";
        }

        if (!isSuccess) {
            message = "操作失败!";
            return AjaxResult.error(message);
        }
        return AjaxResult.success(message);
    }


    /**
     * 获取文章列表信息
     */
    @ApiOperation("文章收藏")
    @PostMapping("/collect")
    //@Anonymous
    public AjaxResult collect(@RequestBody CommunityArticleCollect communityArticleCollect) {
        if (Objects.isNull(communityArticleCollect.getArticleId()) || Objects.isNull(communityArticleCollect.getUserId())) {
            AjaxResult.error("文章或用户信息异常!");
        }
        boolean isSuccess = true;
        String message = "";
        CommunityArticleCollect collect = communityArticleService.selectCommunityCollectById(communityArticleCollect);
        if (Objects.isNull(collect)) {
            //新增收藏
            isSuccess = communityArticleService.insertCommunityCollectById(communityArticleCollect);
            message = "收藏成功";
        } else {
            //删除收藏
            isSuccess = communityArticleService.deleteCommunityCollectById(collect);
            message = "取消收藏";
        }

        if (!isSuccess) {
            message = "操作失败!";
            return AjaxResult.error(message);
        }
        return AjaxResult.success(message);
    }
}